package com.foreverwin.mesnac.common.service.impl;

import cn.hutool.http.HttpUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.foreverwin.mesnac.common.constant.Constants;
import com.foreverwin.mesnac.common.constant.CustomFieldConstant;
import com.foreverwin.mesnac.common.dto.LabelPrintDto;
import com.foreverwin.mesnac.common.dto.SfcDispatchDto;
import com.foreverwin.mesnac.common.enums.DispatchStatusEnum;
import com.foreverwin.mesnac.common.enums.HandleEnum;
import com.foreverwin.mesnac.common.mapper.ProdReadyTaskMapper;
import com.foreverwin.mesnac.common.model.PrintLog;
import com.foreverwin.mesnac.common.model.ProdReadyTask;
import com.foreverwin.mesnac.common.model.ProdReadyTaskDetail;
import com.foreverwin.mesnac.common.service.PrintLogService;
import com.foreverwin.mesnac.common.service.ProdReadyTaskDetailService;
import com.foreverwin.mesnac.common.service.ProdReadyTaskService;
import com.foreverwin.mesnac.common.service.SfcDispatchCommonService;
import com.foreverwin.mesnac.common.util.DateUtil;
import com.foreverwin.mesnac.common.util.StringUtil;
import com.foreverwin.mesnac.meapi.dto.BomComponentDto;
import com.foreverwin.mesnac.meapi.model.Item;
import com.foreverwin.mesnac.meapi.model.Sfc;
import com.foreverwin.mesnac.meapi.model.ShopOrder;
import com.foreverwin.mesnac.meapi.model.WorkCenter;
import com.foreverwin.mesnac.meapi.service.*;
import com.foreverwin.modular.core.exception.BaseException;
import com.foreverwin.modular.core.exception.BusinessException;
import com.foreverwin.modular.core.util.CommonMethods;
import com.foreverwin.modular.core.util.FrontPage;
import org.apache.activemq.ActiveMQConnection;
import org.apache.activemq.ActiveMQConnectionFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.jms.core.JmsMessagingTemplate;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.jms.ConnectionFactory;
import java.math.BigDecimal;
import java.time.LocalDateTime;
import java.util.*;
import java.util.concurrent.TimeUnit;

/**
 * <p>
 * 生产准备任务主表 服务实现类
 * </p>
 *
 * @author Philip
 * @since 2021-06-23
 */
@Service
@Transactional(rollbackFor = Exception.class)
public class ProdReadyTaskServiceImpl extends ServiceImpl<ProdReadyTaskMapper, ProdReadyTask> implements ProdReadyTaskService {

    public static final String P01 = "P01";
    public static final String P02 = "P02";
    public static final String P03 = "P03";
    public static final String STATUS_NEW = "NEW";
    public static final String STATUS_DOING = "DOING";
    public static final String STATUS_FINISH = "FINISH";
    public static final String STATUS_CANCEL = "CANCEL";
    @Value("${spring.activemq.brokerUrl}")
    String brokerURL;
    @Value("${print.server}")
    private String printServer;
    @Autowired
    private ProdReadyTaskMapper prodReadyTaskMapper;
    @Autowired
    private ProdReadyTaskDetailService prodReadyTaskDetailService;
    @Autowired
    private SfcDispatchCommonService sfcDispatchCommonService;
    @Autowired
    private BomComponentService bomComponentService;
    @Autowired
    private CustomFieldsService customFieldsService;
    @Autowired
    private ShopOrderService shopOrderService;
    @Autowired
    private WorkCenterService workCenterService;
    @Autowired
    private PrintLogService printLogService;
    @Autowired
    private ItemService itemService;
    @Autowired
    private SfcService sfcService;

    @Override
    public IPage<ProdReadyTask> selectPage(FrontPage<ProdReadyTask> frontPage, ProdReadyTask prodReadyTask) {
        QueryWrapper<ProdReadyTask> queryWrapper = new QueryWrapper<>();
        queryWrapper.setEntity(prodReadyTask);
        return super.page(frontPage.getPagePlus(), queryWrapper);
    }

    @Override
    public List<ProdReadyTask> selectList(ProdReadyTask prodReadyTask) {
        QueryWrapper<ProdReadyTask> queryWrapper = new QueryWrapper<>();
        queryWrapper.setEntity(prodReadyTask);
        return super.list(queryWrapper);
    }

    @Override
    public void createTask(List<SfcDispatchDto> sfcDispatchDtoList) {
        //根据站点及派工BO查询数据
        String site = CommonMethods.getSite();
        String user = CommonMethods.getUser();
        for (SfcDispatchDto sfcDispatchDto : sfcDispatchDtoList) {
            String sfcDispatchBO = sfcDispatchDto.getHandle();
            String dispatchStatus = sfcDispatchDto.getDispatchStatus();
            String shopOrder = sfcDispatchDto.getShopOrder();
            String sfc = sfcDispatchDto.getSfc();
            String operation = sfcDispatchDto.getOperation();
            String resrce = sfcDispatchDto.getResrce();
            String stepId = sfcDispatchDto.getStepId();
            String workCenter = sfcDispatchDto.getWorkCenter();

            ShopOrder byId = shopOrderService.getById(HandleEnum.SHOP_ORDER.getHandle(site, shopOrder));
            if (DispatchStatusEnum.RELEASE.getCode().equals(dispatchStatus)) {
                ProdReadyTask prodReadyTask = new ProdReadyTask();
                prodReadyTask.setSite(site);
                prodReadyTask.setTaskNo(StringUtil.createQUID());
                prodReadyTask.setHandle(HandleEnum.PROD_READY_TASK.getHandle(site, prodReadyTask.getTaskNo()));
                prodReadyTask.setSfcDispatchBo(sfcDispatchBO);
                prodReadyTask.setShopOrder(shopOrder);
                prodReadyTask.setWorkCenter(workCenter);
                prodReadyTask.setSfc(sfc);
                prodReadyTask.setOperation(operation);
                prodReadyTask.setStepId(stepId);
                prodReadyTask.setItem(StringUtil.trimHandle(byId.getItemBo()));
                prodReadyTask.setResrce(resrce);
                prodReadyTask.setCreateUser(user);
                prodReadyTask.setCreatedDateTime(LocalDateTime.now());
                prodReadyTask.setModifyUser(user);
                prodReadyTask.setModifiedDateTime(LocalDateTime.now());
                List<ProdReadyTaskDetail> prodReadyTaskDetailList = new ArrayList<>();

                String sfcBo = HandleEnum.SFC.getHandle(site, sfc);
                List<BomComponentDto> bomComponentList = bomComponentService.getSfcBomComponent(sfcBo);
                if (!bomComponentList.isEmpty()) {
                    for (BomComponentDto bomComponentDto : bomComponentList) {
                        if (bomComponentDto.getOperation().equals(operation) && bomComponentDto.getStepId().equals(stepId)) {
                            String accessoryType = bomComponentDto.getAccessoryType();
                            //物料P001，校验当前派工单（SFC+工序/步骤）加工是否需要准备物料
                            if (accessoryType == null || accessoryType.equals("0")) {
                                if (prodReadyTaskDetailList.size() > 0) {
                                    long count = prodReadyTaskDetailList.stream().filter(prodReadyTaskDetail -> prodReadyTaskDetail.getInspectionItem().equals(P01)).count();
                                    if (count > 0) {
                                        continue;
                                    }
                                }
                                ProdReadyTaskDetail prodReadyTaskDetail = new ProdReadyTaskDetail();
                                prodReadyTaskDetail.setHandle(HandleEnum.PROD_READY_TASK_DETAIL.getHandle(prodReadyTask.getHandle(), P01));
                                prodReadyTaskDetail.setProdReadyTaskBo(prodReadyTask.getHandle());
                                prodReadyTaskDetail.setInspectionItem(P01);
                                prodReadyTaskDetail.setResult("");
                                prodReadyTaskDetail.setRemarks("");
                                prodReadyTaskDetail.setCreateUser(user);
                                prodReadyTaskDetail.setCreatedDateTime(LocalDateTime.now());
                                prodReadyTaskDetail.setModifyUser(user);
                                prodReadyTaskDetail.setModifiedDateTime(LocalDateTime.now());
                                prodReadyTaskDetailList.add(prodReadyTaskDetail);
                            } else if (accessoryType.equals("1")) {
                                if (prodReadyTaskDetailList.size() > 0) {
                                    long count = prodReadyTaskDetailList.stream().filter(prodReadyTaskDetail -> prodReadyTaskDetail.getInspectionItem().equals(P02)).count();
                                    if (count > 0) {
                                        continue;
                                    }
                                }
                                //刀具P002，校验当前派工单（SFC+工序/步骤）加工是否需要准备物料
                                ProdReadyTaskDetail prodReadyTaskDetail = new ProdReadyTaskDetail();
                                prodReadyTaskDetail.setHandle(HandleEnum.PROD_READY_TASK_DETAIL.getHandle(prodReadyTask.getHandle(), P02));
                                prodReadyTaskDetail.setProdReadyTaskBo(prodReadyTask.getHandle());
                                prodReadyTaskDetail.setInspectionItem(P02);
                                prodReadyTaskDetail.setResult("");
                                prodReadyTaskDetail.setRemarks("");
                                prodReadyTaskDetail.setCreateUser(user);
                                prodReadyTaskDetail.setCreatedDateTime(LocalDateTime.now());
                                prodReadyTaskDetail.setModifyUser(user);
                                prodReadyTaskDetail.setModifiedDateTime(LocalDateTime.now());
                                prodReadyTaskDetailList.add(prodReadyTaskDetail);
                            }
                        }
                    }
                }
                //工控程序P003，工控程序，校验是否需要准备工控程序
                String customFieldsValue = customFieldsService.getCustomFieldsValue(HandleEnum.WORK_CENTER.getHandle(site, workCenter), CustomFieldConstant.WORK_CENTER_CUSTOM_FIELD_PROCESS_CONTROL);
                if (StringUtil.notBlank(customFieldsValue) && customFieldsValue.equals(Constants.STATUS_Y)) {
                    customFieldsValue = customFieldsService.getCustomFieldsValue(HandleEnum.RESOURCE.getHandle(site, resrce), CustomFieldConstant.RESRCE_CUSTOM_FIELD_PROCESS_CONTROL);
                    if (StringUtil.notBlank(customFieldsValue) && customFieldsValue.equals(Constants.STATUS_Y)) {
                        ProdReadyTaskDetail prodReadyTaskDetail = new ProdReadyTaskDetail();
                        prodReadyTaskDetail.setHandle(HandleEnum.PROD_READY_TASK_DETAIL.getHandle(prodReadyTask.getHandle(), P03));
                        prodReadyTaskDetail.setProdReadyTaskBo(prodReadyTask.getHandle());
                        prodReadyTaskDetail.setInspectionItem(P03);
                        prodReadyTaskDetail.setResult("");
                        prodReadyTaskDetail.setRemarks("");
                        prodReadyTaskDetail.setCreateUser(user);
                        prodReadyTaskDetail.setCreatedDateTime(LocalDateTime.now());
                        prodReadyTaskDetail.setModifyUser(user);
                        prodReadyTaskDetail.setModifiedDateTime(LocalDateTime.now());
                        prodReadyTaskDetailList.add(prodReadyTaskDetail);
                    }
                }
                if (prodReadyTaskDetailList.size() > 0) {
                    prodReadyTask.setStatus(STATUS_NEW);
                    prodReadyTaskDetailService.saveBatch(prodReadyTaskDetailList);
                } else {
                    prodReadyTask.setStatus(STATUS_FINISH);
                    prodReadyTask.setResult(Constants.RSESULT_OK);
                    prodReadyTask.setCompleteUser(user);
                    prodReadyTask.setCompleteDateTime(LocalDateTime.now());
                }
                save(prodReadyTask);
            } else if (DispatchStatusEnum.CANCEL.getCode().equals(dispatchStatus)) {
                LambdaQueryWrapper<ProdReadyTask> lambdaQueryWrapper = new LambdaQueryWrapper<>();
                lambdaQueryWrapper.eq(ProdReadyTask::getSfcDispatchBo, sfcDispatchBO);
                lambdaQueryWrapper.orderByDesc(ProdReadyTask::getCreatedDateTime);
                List<ProdReadyTask> list = list(lambdaQueryWrapper);
                if (list.size() < 1) {
                    throw new BaseException("根据派工主键未找到产前准备任务");
                }
                if (list.get(0).getStatus().equals(STATUS_CANCEL)) {
                    throw new BaseException("产前准备任务任务已取消");
                }
                LambdaUpdateWrapper<ProdReadyTask> updateWrapper = new LambdaUpdateWrapper<>();
                updateWrapper.set(ProdReadyTask::getStatus, STATUS_CANCEL);
                updateWrapper.set(ProdReadyTask::getCancelUser, user);
                updateWrapper.set(ProdReadyTask::getCancelDateTime, LocalDateTime.now());
                updateWrapper.eq(ProdReadyTask::getSfcDispatchBo, sfcDispatchBO);
                update(updateWrapper);
            }
        }
    }

    @Override
    public List<ProdReadyTask> getTaskList(ProdReadyTask prodReadyTask) {
        return prodReadyTaskMapper.getTaskList(prodReadyTask, LocaleContextHolder.getLocale().getLanguage());
    }

    @Override
    public ProdReadyTask loadProExecute(String taskBo) {
        ProdReadyTask prodReadyTask = prodReadyTaskMapper.selectById(taskBo);
        if (prodReadyTask.getStatus().equals(STATUS_NEW)) {
            prodReadyTask.setReadyUser(CommonMethods.getUser());
            prodReadyTask.setReadyDateTime(LocalDateTime.now());
            prodReadyTask.setModifyUser(CommonMethods.getUser());
            prodReadyTask.setModifiedDateTime(LocalDateTime.now());
            prodReadyTask.setStatus(STATUS_DOING);
            updateById(prodReadyTask);
        }
        WorkCenter workCenter = new WorkCenter();
        workCenter.setWorkCenter(prodReadyTask.getWorkCenter());
        workCenter.setSite(CommonMethods.getSite());
        List<WorkCenter> workCenters = workCenterService.selectList(workCenter);
        prodReadyTask.setWorkCenterDesc(workCenters.get(0).getDescription());
        prodReadyTask.setDispatchNo(StringUtil.trimHandle(prodReadyTask.getSfcDispatchBo()));
        LambdaQueryWrapper<ProdReadyTaskDetail> lambdaQuery = new LambdaQueryWrapper<>();
        lambdaQuery.eq(ProdReadyTaskDetail::getProdReadyTaskBo, taskBo);
        List<ProdReadyTaskDetail> list = prodReadyTaskDetailService.list(lambdaQuery);
        prodReadyTask.setProdReadyTaskDetailList(list);
        return prodReadyTask;
    }

    @Override
    public List<Map<String, Object>> getInspectionDetailList(Map<String, String> param) {
        String type = param.get("type");
        String dispatchNo = param.get("dispatchNo");
        List<Map<String, Object>> returnMap = new ArrayList<>();
        String site = CommonMethods.getSite();
        if (type.equals(P01)) {
            //物料接收数据
            returnMap = prodReadyTaskMapper.getItemDetail(site, LocaleContextHolder.getLocale().getLanguage(), dispatchNo);
        } else if (type.equals(P02)) {
            //刀具
            returnMap = prodReadyTaskMapper.getToolDetail(site, LocaleContextHolder.getLocale().getLanguage(), dispatchNo);
        } else {
            //通过加工的零件号、设备类型、设备获取发布状态的工控程序
            SfcDispatchDto sfcdispatch=new SfcDispatchDto();
            sfcdispatch.setHandle(HandleEnum.SFC_DISPATCH.getHandle(site,dispatchNo));
            sfcdispatch = sfcDispatchCommonService.findSfcDispatchBySfc(sfcdispatch);
            Sfc sfcServiceById = sfcService.getById(HandleEnum.SFC.getHandle(site, sfcdispatch.getSfc()));
            String itemBo = sfcServiceById.getItemBo();
            JSONObject jsonObject = sendToDnc(StringUtil.trimHandle(itemBo), sfcdispatch.getResrce(), sfcdispatch.getResourceType());
            Map<String, Object> map=new HashMap<>();
            map.put("RESOURCE",sfcdispatch.getResrce());
            map.put("RESOURCE_TYPE",sfcdispatch.getResourceType());
            map.put("RESULT",jsonObject.get("RESULT"));
            map.put("MESSAGE",jsonObject.get("MESSAGE"));
            returnMap.add(map);
        }
        return returnMap;
    }

    @Override
    public boolean saveResult(ProdReadyTask prodReadyTask) {
        String user = CommonMethods.getUser();
        ProdReadyTask byId = getById(prodReadyTask.getHandle());
        if (byId.getStatus().equals(STATUS_CANCEL)) {
            throw new BaseException("产前准备任务任务已取消");
        }
        if (byId.getStatus().equals(STATUS_FINISH) && byId.getResult().equals(Constants.RSESULT_OK)) {
            throw new BaseException("产前准备任务任务已完成");
        }
        List<ProdReadyTaskDetail> prodReadyTaskDetailList = prodReadyTask.getProdReadyTaskDetailList();
        prodReadyTask.setStatus(STATUS_FINISH);
        prodReadyTask.setCompleteUser(user);
        prodReadyTask.setCompleteDateTime(LocalDateTime.now());
        prodReadyTask.setModifyUser(user);
        prodReadyTask.setModifiedDateTime(LocalDateTime.now());
        boolean update = updateById(prodReadyTask);
        if (prodReadyTaskDetailList != null && prodReadyTaskDetailList.size() > 0) {
            for (ProdReadyTaskDetail prodReadyTaskDetail : prodReadyTaskDetailList) {
                prodReadyTaskDetail.setModifyUser(user);
                prodReadyTaskDetail.setModifiedDateTime(LocalDateTime.now());
                prodReadyTaskDetailService.updateById(prodReadyTaskDetail);
            }
        }
        return update;
    }

    @Override
    public void doPrint(ProdReadyTask prodReadyTask) {
        String site = CommonMethods.getSite();
        String user = CommonMethods.getUser();
        String sfcDispatchBo = prodReadyTask.getSfcDispatchBo();
        SfcDispatchDto sfcDispatchDto = new SfcDispatchDto();
        sfcDispatchDto.setHandle(sfcDispatchBo);
        sfcDispatchDto = sfcDispatchCommonService.findSfcDispatchBySfc(sfcDispatchDto);
        List<PrintLog> printList = new ArrayList<>();
        List<LabelPrintDto> labelPrintDtoList = new ArrayList<>();
        String printData = null;
        PrintLog printTag = new PrintLog();

        String resrce = sfcDispatchDto.getResrce();
        String printName = customFieldsService.getCustomFieldsValue(HandleEnum.RESOURCE.getHandle(site, resrce), CustomFieldConstant.RESRCE_CUSTOM_FIELD_PRINT_NAME);
        if (StringUtil.isBlank(printName)) {
            throw new BaseException("资源维护的打印机不能为空");
        }
        String item = prodReadyTask.getItem();
        Item selectCurrent = itemService.selectCurrent(site, item);
        QueryWrapper<PrintLog> queryWrapper = new QueryWrapper();
        queryWrapper.eq(PrintLog.SFC, prodReadyTask.getSfc());
        queryWrapper.eq(PrintLog.STEP_ID, prodReadyTask.getStepId());
        queryWrapper.eq(PrintLog.RESRCE, prodReadyTask.getResrce());
        queryWrapper.eq(PrintLog.CATEGORY, Constants.PRINT_TYPE_SFC);
        queryWrapper.eq(PrintLog.CATEGORY, Constants.PRINT_TYPE_SFC);
        List<PrintLog> printLogList = printLogService.list(queryWrapper);
        if (printLogList.isEmpty()) {
            //打印参数
            LabelPrintDto labelPrintDto = new LabelPrintDto();
            labelPrintDto.setPrinter(printName);
            labelPrintDto.setPrintTemplate(Constants.PRINT_TYPE_SFC);
            labelPrintDto.setItem(sfcDispatchDto.getItem());
            labelPrintDto.setItemDescription(selectCurrent.getDescription());
            labelPrintDto.setSfc(prodReadyTask.getSfc());
            Sfc sfcServiceById = sfcService.getById(HandleEnum.SFC.getHandle(site, prodReadyTask.getSfc()));
            String drawingRevision = customFieldsService.getCustomFieldsValue(sfcServiceById.getItemBo(), CustomFieldConstant.ITEM_DRAWING_REVISION);
            labelPrintDto.setDrawingVersion(drawingRevision);
            labelPrintDto.setQty(new BigDecimal(sfcServiceById.getQty()));
            String workOrder = customFieldsService.getCustomFieldsValue(sfcServiceById.getShopOrderBo(), "WORK_ORDER");
            labelPrintDto.setWorkOrder(workOrder);
            labelPrintDto.setBlankingSize(sfcDispatchDto.getBlankingSize());
            labelPrintDto.setOperation(sfcDispatchDto.getOperation());
            labelPrintDtoList.add(labelPrintDto);
            printData = JSON.toJSONString(labelPrintDtoList);
            //打印记录
            printTag.setHandle(UUID.randomUUID().toString());
            printTag.setPrintName(printName);
            printTag.setPrintTemplate(Constants.PRINT_TYPE_SFC);
            printTag.setSite(site);
            printTag.setCategory(Constants.PRINT_TYPE_SFC);
            printTag.setPrintParam(JSON.toJSONString(labelPrintDtoList));
            printTag.setSfc(prodReadyTask.getSfc());
            printTag.setResrce(prodReadyTask.getResrce());
            printTag.setStepId(prodReadyTask.getStepId());
            printTag.setOperation(prodReadyTask.getOperation());
            printTag.setItemBo(selectCurrent.getHandle());
            printTag.setIsPrint("false");
            printTag.setPrintNum(0);
            printTag.setItem(item);
            printTag.setItemDescription(selectCurrent.getDescription());

            printList.add(printTag);
            printLogService.savePrintLog(site, user, printTag);

        } else {
            printData = printLogList.get(0).getPrintParam();
        }
        String post = HttpUtil.post(printServer, printData, 30000);
        /**
         * {"msg":"打印成功","code":0}
         * {"msg":"打印失败","code":500}
         * 根据返回值，更新打印机信息-printName及打印是否成功信息isPrint
         */
        JSONObject jsonObject = JSONObject.parseObject(post);
        String code = jsonObject.getString("code");
        if (code == null) {

        }
        if (post.indexOf("500") != -1) {
            throw BusinessException.build("打印失败！");
        }
        if (printLogList.isEmpty()) {
            printTag.setIsPrint("true");
            printTag.setPrintNum(1);
            printLogService.updateById(printTag);
        } else {
            PrintLog printLog = printLogList.get(0);
            printTag.setIsPrint("true");
            printTag.setPrintNum(printLog.getPrintNum() + 1);
            printTag.setModifiedDateTime(LocalDateTime.now());
            printTag.setModifyUser(user);
            printLogService.updateById(printLog);
        }

    }

    public JSONObject sendToDnc(String item, String resource, String resourceType) {
        String site = CommonMethods.getSite();
        String queue="resource.check.process";
        JSONObject messageObject=new JSONObject();
        String tranid = UUID.randomUUID().toString();
        messageObject.put("TRANID", tranid);
        String dateTime = DateUtil.formatDate(new Date());
        messageObject.put("DATE_TIME", dateTime);
        messageObject.put("SITE", site);
        messageObject.put("MESSAGE_ID", queue);
        messageObject.put("ITEM", item);
        messageObject.put("RESOURCE", resource);
        messageObject.put("RESOURCE_TYPE", resourceType);
        String causeMessage = null;
        ConnectionFactory connectionFactory = new ActiveMQConnectionFactory(
                ActiveMQConnection.DEFAULT_USER,
                ActiveMQConnection.DEFAULT_PASSWORD, brokerURL);

        JmsMessagingTemplate jmsMessagingTemplate = new JmsMessagingTemplate(connectionFactory);
        jmsMessagingTemplate.getJmsTemplate().setReceiveTimeout(TimeUnit.SECONDS.toMillis(30));
        String message = jmsMessagingTemplate.convertSendAndReceive(queue, messageObject.toString(), String.class);

        if (StringUtil.isBlank(message)) {
            causeMessage = "队列消息消费超时或者未返回消费数据";
        } else {

            JSONObject jsonNode = JSONObject.parseObject(message);
            String result = jsonNode.getString("STATUS");
            if ("S".equalsIgnoreCase(result)) {
                return jsonNode;
            } else {
                causeMessage = jsonNode.getString("MESSAGE");
            }

        }
        JSONObject messageFailObject = new JSONObject();
        messageFailObject.put("TRANID", tranid);
        messageFailObject.put("RESULT", "E");
        messageFailObject.put("MESSAGE", causeMessage);
        return messageFailObject;
    }


}